==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERREQUESTHISTORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERREQUESTHISTORYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERREQUESTHISTORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERREQUESTHISTORYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERREQUESTHISTORYID_Type", propOrder = {
    "customerrequesthistorycode"
})
public class CUSTOMERREQUESTHISTORYID_Type {

    @XmlElement(name = "CUSTOMERREQUESTHISTORYCODE")
    protected String customerrequesthistorycode;

    /**
     * Obtient la valeur de la propriété customerrequesthistorycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERREQUESTHISTORYCODE() {
        return customerrequesthistorycode;
    }

    /**
     * Définit la valeur de la propriété customerrequesthistorycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERREQUESTHISTORYCODE(String value) {
        this.customerrequesthistorycode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERREQUESTHISTORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERREQUESTHISTORYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERREQUESTHISTORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERREQUESTHISTORYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERREQUESTHISTORYID_Type", propOrder = {
    "customerrequesthistorycode"
})
public class CUSTOMERREQUESTHISTORYID_Type {

    @XmlElement(name = "CUSTOMERREQUESTHISTORYCODE")
    protected String customerrequesthistorycode;

    /**
     * Gets the value of the customerrequesthistorycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERREQUESTHISTORYCODE() {
        return customerrequesthistorycode;
    }

    /**
     * Sets the value of the customerrequesthistorycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERREQUESTHISTORYCODE(String value) {
        this.customerrequesthistorycode = value;
    }

}
